@@ -3,7 +3,10 @@ use strict;
 
 package MooseX::Has::Sugar::Saccharin;
 BEGIN {
-  $MooseX::Has::Sugar::Saccharin::VERSION = '0.05044303';
+  $MooseX::Has::Sugar::Saccharin::AUTHORITY = 'cpan:KENTNL';
+}
+{
+  $MooseX::Has::Sugar::Saccharin::VERSION = '0.05070421';
 }
 
 # ABSTRACT: Experimental sweetness
@@ -126,12 +129,13 @@ MooseX::Has::Sugar::Saccharin - Experimental sweetness
 
 =head1 VERSION
 
-version 0.05044303
+version 0.05070421
 
 =head1 SYNOPSIS
 
 This is a highly experimental sugaring module. No Guarantees of stability.
 
+    use MooseX::Types::Moose qw( :all );
     has name   => rw Str, default { 1 };
     has suffix => required rw Str;
     has 'suffix', required rw Str;
@@ -319,7 +323,7 @@ Kent Fredric <kentnl at cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Kent Fredric.
+This software is copyright (c) 2012 by Kent Fredric.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
